@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0405';
+our $VERSION = '0.0406';
 
 use Moo;
 use Music::Chord::Note;
@@ -44,6 +44,8 @@ sub cadence {
     $args{leading}   ||= 1;
     $args{variation} ||= 1;
 
+    die 'unknown leader' if $args{leading} < 1 or $args{leading} > 7;
+
     my @scale = get_scale_notes( $args{key}, $args{scale} );
 
     my $mcn = Music::Chord::Note->new;
@@ -136,7 +138,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0405
+version 0.0406
 
 =head1 SYNOPSIS
 
@@ -237,8 +239,8 @@ Supported cadences are:
   plagal
   deceptive
 
-The B<leading> chord is a number for each diatonic scale chord to use
-for the first C<half> cadence chord.  So for the key of C<C major>
+The B<leading> chord is a number (1-7) for each diatonic scale chord
+to use for the first C<half> cadence chord.  For the key of C<C major>
 this is:
 
   CM: 1
